PCB Environment: dsn::Placement Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Placement Struct Reference

## Public Member Functions
std::string | str () const

## Data Fields
std::string | name
dsn::Image * | image {0}
double | x
double | pinref_x
double | y
double | pinref_y
int | z
int | angle {0}
double | clearance {0}
bool | via_ok {true}
bool | can_route {false}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp